package jp.gr.java_conf.akabeko.svgviewer;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import com.larvalabs.svgandroid.SVG;
import com.larvalabs.svgandroid.SVGParser;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.widget.ImageView;

/**
 * SVG ファイルの内容を表示するための画面を表します。
 */
public class SvgViewActivity extends Activity {
	/**
	 * SVG ファイルのパスを示す設定名。
	 */
	public static final String EXTRA_SVG_PATH = "SVG_PATH";

	/**
	 * SVG ファイルの入力ストリーム。
	 */
	private InputStream mStream;

	/**
	 * SVG ファイルの内容を画像として表示するための ImageView。
	 */
	private ImageView mSvgImageView;

	/**
	 * SVG ファイルを読み込みます。
	 *
	 * @param path SVG ファイルへのパス情報。
	 */
	private void loadSvg( String path ) {
		try {
			this.mStream = new FileInputStream( new File( path ) );

			SVG svg = SVGParser.getSVGFromInputStream( this.mStream );
			if( svg != null ) {
				this.mSvgImageView.setImageDrawable( svg.createPictureDrawable() );
			}

		} catch( Exception e ) {
			this.showErrorMessage( e.getMessage() );
		}
	}

	/**
	 * 画面が作成される時に発生します。
	 *
	 * @param savedInstanceState 保存されたインスタンス情報。
	 */
	@Override
	public void onCreate( Bundle savedInstanceState ) {
		super.onCreate( savedInstanceState );
		this.setContentView( R.layout.svg_view );

		this.mSvgImageView = ( ImageView )this.findViewById( R.id.svg_image );

		Intent intent = this.getIntent();
		if( intent != null ) {
			this.loadSvg( intent.getStringExtra( EXTRA_SVG_PATH ) );
		}
	}

	/**
	 * 画面が破棄される時に発生します。
	 */
	@Override
	protected void onDestroy() {
		if( this.mStream != null ) {
			try {
				this.mStream.close();

			} catch( IOException e ) {
				e.printStackTrace();
			}
		}

		this.mSvgImageView.setImageDrawable( null );
		super.onDestroy();
	}

	/**
	 * エラーメッセージを表示して Activity を終了します。
	 *
	 * @param message メッセージ。
	 */
	private void showErrorMessage( String message ) {
		AlertDialog alert = new AlertDialog.Builder( this ).create();
		alert.setCancelable( false );
		alert.setTitle( "Error" );
		alert.setMessage( message );
		alert.setButton( "OK", new DialogInterface.OnClickListener() {
			public void onClick( DialogInterface dialog, int which ) {
				dialog.dismiss();
				finish();
			}
		} );
		alert.show();
	}
}
