package jp.gr.java_conf.akabeko.svgviewer;

import java.io.File;

import jp.gr.java_conf.akabeko.svgviewer.model.SvgFileFilter;
import jp.gr.java_conf.akabeko.svgviewer.widget.FileListItemAdapter;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

/**
 * アプリケーションのトップ画面を表します。
 */
public class TopActivity extends Activity implements OnItemClickListener, OnClickListener {
	/**
	 * 現在のディレクトリ パスを表示するための TextView。
	 */
	private TextView mCurrentDirTextView;

	/**
	 * ファイル情報のコレクション。
	 */
	private FileListItemAdapter mFileListAdapter;

	/**
	 * ファイル一覧。
	 */
	private ListView mFileListView;

	/**
	 * SVG ファイルとサブ ディレクトリのフィルター。
	 */
	private SvgFileFilter mFilter = new SvgFileFilter();

	/**
	 * 親ディレクトリ。
	 */
	private String mParentDir;

	/**
	 * 上の階層へ移動するためのボタン。
	 */
	private Button mUpDirButton;

	/**
	 * コントロールを初期化します。
	 */
	private void initControls() {
		this.mUpDirButton = ( Button )this.findViewById( R.id.up_dir );
		this.mUpDirButton.setOnClickListener( this );

		this.mCurrentDirTextView = ( TextView )this.findViewById( R.id.current_dir );

		this.mFileListAdapter = new FileListItemAdapter( this, R.layout.list_item );

		this.mFileListView = ( ListView )this.findViewById( R.id.file_list );
		this.mFileListView.setAdapter( this.mFileListAdapter );
		this.mFileListView.setOnItemClickListener( this );

		this.updateFileList( new File( "/" ) );
	}

	/**
	 * View がクリックされた時に発生します。
	 *
	 * @param v クリックされた View。
	 */
	public void onClick( View v ) {
		switch( v.getId() ) {
		case R.id.up_dir:
			if( mParentDir != null ) {
				updateFileList( new File( mParentDir ) );
			}
			break;
		}
	}

	/**
	 * 画面が作成される時に発生します。
	 *
	 * @param savedInstanceState 保存されたインスタンス情報。
	 */
	@Override
	public void onCreate( Bundle savedInstanceState ) {
		super.onCreate( savedInstanceState );
		this.setContentView( R.layout.top );
		this.initControls();
	}

	/**
	 * リスト上のアイテムがクリックされた時に発生します。
	 *
	 * @param parent   親となる View。
	 * @param view     クリックされた View。
	 * @param position アイテムの位置。
	 * @param id       アイテムの識別子。
	 */
	public void onItemClick( AdapterView< ? > parent, View view, int position, long id ) {
		File file = this.mFileListAdapter.getItem( position );
		if( file == null ) { return; }

		if( file.isDirectory() ) {
			this.updateFileList( file );

		} else {
			Intent intent = new Intent();
			intent.setClass( this, SvgViewActivity.class );
			intent.putExtra( SvgViewActivity.EXTRA_SVG_PATH, file.getAbsolutePath() );
			this.startActivity( intent );
		}
	}

	/**
	 * ファイル一覧を更新します。
	 *
	 * @param dir ディレクトリ。
	 */
	private void updateFileList( File dir ) {
		this.mCurrentDirTextView.setText( dir.getPath() );

		// 親ディレクトリの有無で移動きりかえ
		this.mParentDir = dir.getParent();
		this.mUpDirButton.setEnabled( this.mParentDir != null );

		// ファイル一覧の更新
		{
			this.mFileListAdapter.clear();

			File[] files = dir.listFiles( mFilter );
			if( files != null ) {
				for( File file : files ) {
					this.mFileListAdapter.add( file );
				}
			}

			this.mFileListAdapter.notifyDataSetChanged();
		}
	}
}