package jp.gr.java_conf.akabeko.svgviewer.widget;

import java.io.File;

import com.larvalabs.svgandroid.SVG;
import com.larvalabs.svgandroid.SVGParser;

import jp.gr.java_conf.akabeko.svgviewer.R;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

/**
 * ファイル情報のコレクションを管理します。
 */
public class FileListItemAdapter extends ArrayAdapter< File > {
	/**
	 * ファイルのアイコン。
	 */
	private Drawable mFileIcon;

	/**
	 * フォルダのアイコン。
	 */
	private Drawable mFolderIcon;

	/**
	 * レイアウト操作用インスタンス。
	 */
	private LayoutInflater mLayoutInflater;

	/**
	 * インスタンスを初期化します。
	 *
	 * @param context            コンテキスト。
	 * @param textViewResourceId レイアウト。
	 * @param objects            管理対象とするアイテムのコレクション。
	 */
	public FileListItemAdapter( Context context, int textViewResourceId ) {
		super( context, textViewResourceId );
		this.mLayoutInflater = ( LayoutInflater )context.getSystemService( Context.LAYOUT_INFLATER_SERVICE );

		Resources r = context.getResources();
		this.mFileIcon   = this.loadIcon( r, R.drawable.ic_file   );
		this.mFolderIcon = this.loadIcon( r, R.drawable.ic_folder );
	}

	/**
	 * アイテムの View を取得します。
	 *
	 * @param position    アイテムのコレクションにおけるインデックス。
	 * @param convertView アイテムの規定s View。
	 * @param parent      親となる View。
	 *
	 * @return アイテムの View。
	 */
	@Override
	public View getView( int position, View convertView, ViewGroup parent ) {
		View view = convertView;
		if( view == null ) {
			view = this.mLayoutInflater.inflate( R.layout.list_item, null );
		}

		File file = this.getItem( position );

		// アイコン
		ImageView image = ( ImageView )view.findViewById( R.id.list_item_icon );
		if( image != null ) {
			image.setImageDrawable( file.isDirectory() ? this.mFolderIcon : this.mFileIcon );
		}

		// テキスト
		TextView text = ( TextView )view.findViewById( R.id.list_item_text );
		if( text != null ) {
			text.setText( file.getName() );
		}

		return view;
	}

	/**
	 * SVG 形式のアイコンを Drawable として読み込みます。
	 *
	 * @param r  リソース管理オブジェクトのインスタンス。
	 * @param id アイコンのリソース識別子。
	 *
	 * @return 読み込まれた Drawable。
	 */
	private Drawable loadIcon( Resources r, int id ) {
		SVG svg = SVGParser.getSVGFromResource( r, id );
		return svg.createPictureDrawable();
	}
}
